@@ -6,7 +6,7 @@ use Time::HiRes qw(sleep);
 use JSON::PP ();
 use Scalar::Util qw(looks_like_number);
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 my %COLLECTORS = (
     system  => \&_system_info,
@@ -292,6 +292,83 @@ sub to_json {
     return $encoder->encode($data);
 }
 
+sub to_yaml {
+    my ($data) = @_;
+    my $yaml = _yaml_dump($data, 0);
+    $yaml .= "\n" unless $yaml =~ /\n\z/;
+    return $yaml;
+}
+
+sub _yaml_dump {
+    my ($data, $indent) = @_;
+    my $prefix = '  ' x $indent;
+
+    if (!defined $data) {
+        return $prefix . "null\n";
+    }
+
+    if (!ref $data) {
+        return $prefix . _yaml_scalar($data) . "\n";
+    }
+
+    if (ref $data eq 'HASH') {
+        my $out = '';
+        for my $key (sort keys %$data) {
+            my $value = $data->{$key};
+            if (_yaml_is_simple($value)) {
+                $out .= $prefix . $key . ': ' . _yaml_scalar($value) . "\n";
+            } else {
+                $out .= $prefix . "$key:\n" . _yaml_dump($value, $indent + 1);
+            }
+        }
+        return $out eq '' ? $prefix . "{}\n" : $out;
+    }
+
+    if (ref $data eq 'ARRAY') {
+        return $prefix . "[]\n" unless @$data;
+
+        my $out = '';
+        for my $value (@$data) {
+            if (_yaml_is_simple($value)) {
+                $out .= $prefix . '- ' . _yaml_scalar($value) . "\n";
+            } else {
+                $out .= $prefix . "-\n" . _yaml_dump($value, $indent + 1);
+            }
+        }
+        return $out;
+    }
+
+    return $prefix . _yaml_scalar($data) . "\n";
+}
+
+sub _yaml_is_simple {
+    my ($value) = @_;
+    return !ref($value);
+}
+
+sub _yaml_scalar {
+    my ($value) = @_;
+
+    return 'null' unless defined $value;
+
+    if (looks_like_number($value) && $value !~ /^0[0-9]/) {
+        return $value;
+    }
+
+    if ($value eq '') {
+        return "''";
+    }
+
+    if ($value =~ /[\s#:>{}\[\],]|\A[-?]|\n/) {
+        my $escaped = $value;
+        $escaped =~ s/'/''/g;
+        $escaped =~ s/\n/\\n/g;
+        return "'$escaped'";
+    }
+
+    return $value;
+}
+
 sub _timestamp {
     my @t = gmtime();
     return sprintf("%04d-%02d-%02dT%02d:%02d:%02dZ", $t[5]+1900,$t[4]+1,@t[3,2,1,0]);
@@ -352,7 +429,7 @@ __END__
 
 =head1 NAME
 
-Sys::Monitor::Lite - Lightweight system monitoring toolkit with JSON output
+Sys::Monitor::Lite - Lightweight system monitoring toolkit with JSON/YAML output
 
 =head1 SYNOPSIS
 
@@ -361,8 +438,9 @@ Sys::Monitor::Lite - Lightweight system monitoring toolkit with JSON output
 
 =head1 DESCRIPTION
 
-A minimal system monitor that outputs structured JSON data
-for easy automation and integration with jq-lite.
+A minimal system monitor that outputs structured JSON or YAML data
+for easy automation and integration with jq-lite, yq, or other
+tools that consume structured logs.
 
 =head1 FUNCTIONS
 
@@ -395,18 +473,21 @@ Returns a sorted list of metric names that the module can collect.
 Serialises the supplied data structure to a JSON string using
 L<JSON::PP>. Pass C<pretty =E<gt> 1> to enable human-readable output.
 
+=head2 to_yaml
+
+    my $yaml = Sys::Monitor::Lite::to_yaml($data);
+
+Serialises the supplied data structure to a YAML string using a
+minimal built-in emitter.
+
 =head1 EXPORT
 
 This module does not export any symbols by default. Functions can be
 called with their fully-qualified names, e.g. C<Sys::Monitor::Lite::collect_all()>.
 
-=head1 SEE ALSO
-
-L<script/sys-monitor-lite> – command-line interface for this module.
-
 =head1 AUTHOR
 
-Shingo Kawamura E<lt>kpannakoota1@gmail.comE<gt>
+Shingo Kawamura E<lt>pannakoota1@gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
